@@ -264,14 +264,6 @@ SCIP_RETCODE SCIPbendersMergeSubproblemIntoMaster(
    int                   probnumber          /**< the number of the subproblem that will be merged into the master problem*/
    );
 
-/** Applies a Benders' decomposition to the problem based upon the decomposition selected from the storage */
-extern
-SCIP_RETCODE SCIPbendersApplyDecomposition(
-   SCIP_BENDERS*         benders,            /**< Benders' decomposition */
-   SCIP_SET*             set,                /**< global SCIP settings */
-   SCIP_DECOMP*          decomp              /**< the decomposition to apply to the problem */
-   );
-
 /** sets priority of Benders' decomposition */
 void SCIPbendersSetPriority(
    SCIP_BENDERS*         benders,            /**< Benders' decomposition */
@@ -421,6 +413,15 @@ SCIP_Bool SCIPbendersGetMastervarsCont(
    int                   probnumber          /**< the subproblem number */
    );
 
+/** sets the objective type for the aggregation of the Benders' decomposition subproblem objectives. This is either the
+ * summation of the objective values or a minimax of the objective values (such as for a makespan objective)
+ */
+SCIP_EXPORT
+void SCIPbendersSetObjectiveType(
+   SCIP_BENDERS*         benders,            /**< Benders' decomposition */
+   SCIP_BENDERSOBJTYPE   objectivetype       /**< the objective type */
+   );
+
 /** adds the data for the generated cuts to the Benders' cut storage */
 SCIP_RETCODE SCIPbendersStoreCut(
    SCIP_BENDERS*         benders,            /**< Benders' decomposition cut */
