@@ -1,19 +1,18 @@
 #ifndef __CONFIG_H__
 #define __CONFIG_H__
 
-#define CMAKE_BUILD_TYPE "RelWithDebInfo"
-#define SCIP_VERSION_MAJOR 9
-#define SCIP_VERSION_MINOR 2
-#define SCIP_VERSION_PATCH 3
-#define SCIP_VERSION_SUB 0
-#define SCIP_VERSION_API 115
+#define SCIP_BUILD_TYPE "RelWithDebInfo"
+#define SCIP_VERSION_MAJOR 10
+#define SCIP_VERSION_MINOR 0
+#define SCIP_VERSION_PATCH 0
+#define SCIP_VERSION_API 156
 /* #undef BMS_NOBLOCKMEM */
 /* #undef SCIP_NOBUFFERMEM */
 /* #undef WITH_DEBUG_SOLUTION */
 /* #undef SCIP_NO_SIGACTION */
 /* #undef SCIP_NO_STRTOK_R */
-#define TPI_NONE
-/* #undef TPI_TNY */
+/* #undef TPI_NONE */
+#define TPI_TNY
 /* #undef TPI_OMP */
 #define SCIP_THREADSAFE
 #define WITH_SCIPDEF
@@ -22,11 +21,17 @@
 #define SCIP_WITH_ZLIB
 #define SCIP_WITH_READLINE
 #define SCIP_WITH_GMP
+/* #undef SCIP_WITH_MPFR */
+/* #undef SCIP_WITH_QSOPTEX */
 /* #undef SCIP_WITH_LPSCHECK */
 /* #undef SCIP_WITH_ZIMPL */
 #define SCIP_WITH_AMPL
 #define SCIP_ROUNDING_FE
 /* #undef SCIP_ROUNDING_FP */
 /* #undef SCIP_ROUNDING_MS */
+/* #undef SCIP_WITH_EXACTSOLVE */
+/* #undef SCIP_WITH_EGLIB */
+/* #undef SCIP_WITH_BOOST */
+/* #undef SCIP_CHECK_STAGE */
 
 #endif
