@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -142,8 +142,7 @@
 #include "scip/type_event.h"
 #include "scip/type_message.h"
 #include <string.h>
-#if defined(_WIN32) || defined(_WIN64)
-#else
+#ifndef _WIN32
 #include <strings.h> /*lint --e{766}*/
 #endif
 
@@ -282,10 +281,8 @@ void SCIPconflicthdlrEnableOrDisableClocks(
    SCIP_Bool             enable              /**< should the clocks of the conflict handler be enabled? */
    );
 
-/** return TRUE if conflict analysis is applicable; In case the function return FALSE there is no need to initialize the
- *  conflict analysis since it will not be applied
- */
-SCIP_Bool SCIPconflictApplicable(
+/** return TRUE if conflict graph analysis is applicable */
+SCIP_Bool SCIPconflictGraphApplicable(
    SCIP_SET*             set                 /**< global SCIP settings */
    );
 
@@ -350,7 +347,7 @@ SCIP_RETCODE SCIPconflictAnalyzeRemainingBdchgs(
    int*                  nreconvliterals     /**< pointer to store the number of literals generated reconvergence constraints */
    );
 
-/** initializes the propagation conflict analysis by clearing the conflict candidate queue */
+/** initializes propagation and resolution conflict analysis by clearing the conflict candidate queues */
 SCIP_RETCODE SCIPconflictInit(
    SCIP_CONFLICT*        conflict,           /**< conflict analysis data */
    SCIP_SET*             set,                /**< global SCIP settings */
@@ -434,6 +431,7 @@ SCIP_RETCODE SCIPrunBoundHeuristic(
    SCIP_REOPT*           reopt,              /**< reoptimization data */
    SCIP_LP*              lp,                 /**< LP data */
    SCIP_LPI*             lpi,                /**< LPI data */
+   SCIP_EVENTFILTER*     eventfilter,        /**< global event filter */
    BMS_BLKMEM*           blkmem,             /**< block memory */
    SCIP_Real*            proofcoefs,         /**< coefficients in the proof constraint */
    SCIP_Real*            prooflhs,           /**< lhs of the proof constraint */
@@ -448,6 +446,15 @@ SCIP_RETCODE SCIPrunBoundHeuristic(
    SCIP_Bool*            valid               /**< pointer to store whether the result is still a valid proof */
    );
 
+void conflictsetPrint(
+   SCIP_CONFLICTSET*     conflictset         /**< conflict set */
+   );
+
+SCIP_Bool bdchginfoIsInvalid(
+   SCIP_CONFLICT*        conflict,           /**< conflict analysis data */
+   SCIP_BDCHGINFO*       bdchginfo           /**< bound change information */
+   );
+
 #ifdef __cplusplus
 }
 #endif
