@@ -352,6 +352,13 @@ SCIP_ROW* SCIPgetRowLinear(
    SCIP_CONS*            cons                /**< constraint data */
    );
 
+/** creates and returns the row of the given linear constraint */
+SCIP_EXPORT
+SCIP_RETCODE SCIPcreateRowLinear(
+   SCIP*                 scip,               /**< SCIP data structure */
+   SCIP_CONS*            cons                /**< constraint data */
+   );
+
 /** tries to automatically convert a linear constraint into a more specific and more specialized constraint */
 SCIP_EXPORT
 SCIP_RETCODE SCIPupgradeConsLinear(
@@ -360,6 +367,7 @@ SCIP_RETCODE SCIPupgradeConsLinear(
    SCIP_CONS**           upgdcons            /**< pointer to store upgraded constraint, or NULL if not successful */
    );
 
+
 /** performs linear constraint type classification as used for MIPLIB
  *
  *  iterates through all linear constraints and stores relevant statistics in the linear constraint statistics \p linconsstats.
@@ -380,8 +388,9 @@ SCIP_EXPORT
 SCIP_RETCODE SCIPcleanupConssLinear(
    SCIP*                 scip,               /**< SCIP data structure */
    SCIP_Bool             onlychecked,        /**< should only checked constraints be cleaned up? */
-   SCIP_Bool*            infeasible          /**< pointer to return whether the problem was detected to be infeasible */
-   );
+   SCIP_Bool*            infeasible,         /**< pointer to return whether the problem was detected to be infeasible */
+   int*                  ndelconss           /**< pointer to count number of deleted constraints */
+);
 
 /** @} */
 
