@@ -99,14 +99,6 @@
 #define SCIP_Shortbool uint8_t               /**< type used for Boolean values with less space */
 #endif
 
-/*
- * Add some macros for differing functions on Windows
- */
-#ifdef _WIN32
-#define strcasecmp _stricmp
-#define strncasecmp _strnicmp
-#endif
-
 /*
  * Define the macro SCIP_EXPORT if it is not included from the generated header
  */
@@ -131,20 +123,12 @@
 
 
 #define SCIP_VERSION     (100*SCIP_VERSION_MAJOR + 10*SCIP_VERSION_MINOR + SCIP_VERSION_PATCH) /**< SCIP version number (multiplied by 100 to get integer number) */
-#define SCIP_SUBVERSION  SCIP_VERSION_SUB  /**< SCIP sub version number */
+#define SCIP_VERSION_SUB 0                 /**< @deprecated SCIP sub version number. Always 0. */
+#define SCIP_SUBVERSION  SCIP_VERSION_SUB  /**< @deprecated SCIP sub version number. Always 0. */
 #define SCIP_APIVERSION  SCIP_VERSION_API  /**< SCIP API version number */
 #define SCIP_COPYRIGHT   "Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)"
 
 
-/*
- * CIP format variable characters
- */
-
-#define SCIP_VARTYPE_BINARY_CHAR 'B'
-#define SCIP_VARTYPE_INTEGER_CHAR 'I'
-#define SCIP_VARTYPE_IMPLINT_CHAR 'M'
-#define SCIP_VARTYPE_CONTINUOUS_CHAR 'C'
-
 /*
  * Long Integer values
  */
@@ -170,8 +154,10 @@
  */
 
 #define SCIP_Real double                               /**< type used for floating point values */
+
 #define SCIP_REAL_MAX         (SCIP_Real)DBL_MAX
 #define SCIP_REAL_MIN        -(SCIP_Real)DBL_MAX
+#define SCIP_REAL_UNITROUNDOFF        (1.0 / 9007199254740992)
 #define SCIP_REAL_FORMAT               "lf"
 
 #define SCIP_DEFAULT_INFINITY         1e+20  /**< default value considered to be infinity */
