@@ -65,6 +65,23 @@
 #include "scip/struct_misc.h"
 #endif
 
+/* The C99 standard defines the function (or macro) isfinite.
+ * On MacOS X, isfinite is also available.
+ * From the BSD world, there comes a function finite.
+ * On SunOS, finite is also available.
+ * In the MS compiler world, there is a function _finite.
+ * As last resort, we check whether x == x does not hold, but this works only for NaN's, not for infinities!
+ */
+#if _XOPEN_SOURCE >= 600 || defined(_ISOC99_SOURCE) || _POSIX_C_SOURCE >= 200112L || defined(__APPLE__)
+#define SCIPisFinite isfinite
+#elif defined(_BSD_SOURCE) || defined(__sun)
+#define SCIPisFinite finite
+#elif defined(_MSC_VER)
+#define SCIPisFinite _finite
+#else
+#define SCIPisFinite(x) ((x) == (x))
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -575,8 +592,34 @@ int SCIPpqueueFind(
 INLINE static
 uint32_t SCIPrealHashCode(double x)
 {
+   uint16_t mantissa;
+   int thenum;
    int theexp;
-   return (((uint32_t)(uint16_t)(int16_t)ldexp(frexp(x, &theexp), 15))<<16) | (uint32_t)(uint16_t)theexp;
+
+   /* hashing infinite or nan values is not supported */
+   assert(SCIPisFinite(x));
+
+   /* get 16 digits of absolute mantissa */
+   mantissa = (uint16_t)ldexp(frexp(ABS(x), &theexp), 16) + 1;
+
+   /* pave sign bit with overflow */
+   if( mantissa == 0 )  /* cppcheck-suppress knownConditionTrueFalse */
+   {
+      /* divide overflow 2^16 by four */
+      mantissa = 1 << 14;
+
+      /* increment the exponent */
+      ++theexp;
+   }
+   /* pave sign bit without overflow */
+   else
+      /* divide mantissa by two */
+      mantissa >>= 1;
+
+   /* determine mantissa hash */
+   thenum = x < 0.0 ? -(int)mantissa : (int)mantissa;
+
+   return (((uint32_t)(uint16_t)theexp) << 16) | ((uint32_t)(uint16_t)thenum);
 }
 
 /** creates a hash table */
@@ -597,19 +640,6 @@ void SCIPhashtableFree(
    SCIP_HASHTABLE**      hashtable           /**< pointer to the hash table */
    );
 
-/** removes all elements of the hash table
- *
- *  @note From a performance point of view you should not fill and clear a hash table too often since the clearing can
- *        be expensive. Clearing is done by looping over all buckets and removing the hash table lists one-by-one.
- *
- *  @deprecated Please use SCIPhashtableRemoveAll()
- */
-SCIP_EXPORT
-SCIP_DEPRECATED
-void SCIPhashtableClear(
-   SCIP_HASHTABLE*       hashtable           /**< hash table */
-   );
-
 /** inserts element in hash table (multiple inserts of same element override the previous entry) */
 SCIP_EXPORT
 SCIP_RETCODE SCIPhashtableInsert(
@@ -862,6 +892,14 @@ SCIP_RETCODE SCIPhashmapInsert(
    void*                 image               /**< new image for origin */
    );
 
+/** inserts new origin->image pair in hash map (must not be called for already existing origins!) */
+SCIP_EXPORT
+SCIP_RETCODE SCIPhashmapInsertLong(
+   SCIP_HASHMAP*         hashmap,            /**< hash map */
+   void*                 origin,             /**< origin to set image for */
+   SCIP_Longint          image               /**< new image for origin */
+   );
+
 /** inserts new origin->image pair in hash map (must not be called for already existing origins!) */
 SCIP_EXPORT
 SCIP_RETCODE SCIPhashmapInsertInt(
@@ -892,6 +930,13 @@ int SCIPhashmapGetImageInt(
    void*                 origin              /**< origin to retrieve image for */
    );
 
+/** retrieves image of given origin from the hash map, or SCIP_LONGINT_MAX if no image exists */
+SCIP_EXPORT
+SCIP_Longint SCIPhashmapGetImageLong(
+   SCIP_HASHMAP*         hashmap,            /**< hash map */
+   void*                 origin              /**< origin to retrieve image for */
+   );
+
 /** retrieves image of given origin from the hash map, or SCIP_INVALID if no image exists */
 SCIP_EXPORT
 SCIP_Real SCIPhashmapGetImageReal(
@@ -1864,6 +1909,12 @@ SCIP_Bool SCIPrealToRational(
    SCIP_Longint*         denominator         /**< pointer to store the denominator d of the rational number */
    );
 
+/** checks, if value is integral without any tolerances */
+SCIP_EXPORT
+SCIP_Bool SCIPrealIsExactlyIntegral(
+   SCIP_Real             val                 /**< value to process */
+   );
+
 /** tries to find a value, such that all given values, if scaled with this value become integral in relative allowed
  *  difference in between mindelta and maxdelta
  */
@@ -1879,6 +1930,17 @@ SCIP_RETCODE SCIPcalcIntegralScalar(
    SCIP_Bool*            success             /**< stores whether returned value is valid */
    );
 
+/** tries to find a value, such that all given values, if scaled with this value become integral */
+SCIP_EXPORT
+SCIP_RETCODE SCIPcalcIntegralScalarExact(
+   BMS_BUFMEM*           buffer,             /**< buffer memory */
+   SCIP_RATIONAL**       vals,               /**< values to scale */
+   int                   nvals,              /**< number of values to scale */
+   SCIP_Real             maxscale,           /**< maximal allowed scalar */
+   SCIP_RATIONAL*        intscalar,          /**< pointer to store scalar that would make the coefficients integral */
+   SCIP_Bool*            success             /**< stores whether returned value is valid */
+   );
+
 /** given a (usually very small) interval, tries to find a rational number with simple denominator (i.e. a small
  *  number, probably multiplied with powers of 10) out of this interval; returns TRUE iff a valid rational
  *  number inside the interval was found
@@ -1917,23 +1979,6 @@ SCIP_Real SCIPcalcRootNewton(
    int                   k                   /**< iteration limit */
    );
 
-/* The C99 standard defines the function (or macro) isfinite.
- * On MacOS X, isfinite is also available.
- * From the BSD world, there comes a function finite.
- * On SunOS, finite is also available.
- * In the MS compiler world, there is a function _finite.
- * As last resort, we check whether x == x does not hold, but this works only for NaN's, not for infinities!
- */
-#if _XOPEN_SOURCE >= 600 || defined(_ISOC99_SOURCE) || _POSIX_C_SOURCE >= 200112L || defined(__APPLE__)
-#define SCIPisFinite isfinite
-#elif defined(_BSD_SOURCE) || defined(__sun)
-#define SCIPisFinite finite
-#elif defined(_MSC_VER)
-#define SCIPisFinite _finite
-#else
-#define SCIPisFinite(x) ((x) == (x))
-#endif
-
 /* In debug mode, the following methods are implemented as function calls to ensure
  * type validity.
  */
@@ -1978,19 +2023,6 @@ SCIP_Real SCIPcomputeGap(
  *@{
  */
 
-/** returns a random integer between minrandval and maxrandval
- *
- *  @deprecated Please use SCIPrandomGetInt() to request a random integer.
- */
-SCIP_EXPORT
-SCIP_DEPRECATED
-int SCIPgetRandomInt(
-   int                   minrandval,         /**< minimal value to return */
-   int                   maxrandval,         /**< maximal value to return */
-   unsigned int*         seedp               /**< pointer to seed value */
-   );
-
-
 /** returns a random integer between minrandval and maxrandval */
 SCIP_EXPORT
 int SCIPrandomGetInt(
@@ -2019,33 +2051,6 @@ SCIP_Real SCIPrandomGetReal(
    SCIP_Real             maxrandval          /**< maximal value to return */
    );
 
-/** returns a random real between minrandval and maxrandval
- *
- *  @deprecated Please use SCIPrandomGetReal() to request a random real.
- */
-SCIP_EXPORT
-SCIP_DEPRECATED
-SCIP_Real SCIPgetRandomReal(
-   SCIP_Real             minrandval,         /**< minimal value to return */
-   SCIP_Real             maxrandval,         /**< maximal value to return */
-   unsigned int*         seedp               /**< pointer to seed value */
-   );
-
-/** draws a random subset of disjoint elements from a given set of disjoint elements;
- *  this implementation is suited for the case that nsubelems is considerably smaller then nelems
- *
- *  @deprecated Please use SCIPrandomGetSubset()
- */
-SCIP_EXPORT
-SCIP_DEPRECATED
-SCIP_RETCODE SCIPgetRandomSubset(
-   void**                set,                /**< original set, from which elements should be drawn */
-   int                   nelems,             /**< number of elements in original set */
-   void**                subset,             /**< subset in which drawn elements should be stored */
-   int                   nsubelems,          /**< number of elements that should be drawn and stored */
-   unsigned int          randseed            /**< seed value for random generator */
-   );
-
 /**@} */
 
 /*
@@ -2080,23 +2085,6 @@ void SCIPswapPointers(
    void**                pointer2            /**< second pointer */
    );
 
-/** randomly shuffles parts of an integer array using the Fisher-Yates algorithm
- *
- *  @deprecated Please use SCIPrandomPermuteIntArray()
- */
-SCIP_EXPORT
-SCIP_DEPRECATED
-void SCIPpermuteIntArray(
-   int*                  array,              /**< array to be shuffled */
-   int                   begin,              /**< first included index that should be subject to shuffling
-                                              *   (0 for first array entry)
-                                              */
-   int                   end,                /**< first excluded index that should not be subject to shuffling
-                                              *   (array size for last array entry)
-                                              */
-   unsigned int*         randseed            /**< seed value for the random generator */
-   );
-
 /** randomly shuffles parts of an integer array using the Fisher-Yates algorithm */
 SCIP_EXPORT
 void SCIPrandomPermuteIntArray(
@@ -2123,23 +2111,6 @@ void SCIPrandomPermuteArray(
                                               */
    );
 
-/** randomly shuffles parts of an array using the Fisher-Yates algorithm
- *
- *  @deprecated Please use SCIPrandomPermuteArray()
- */
-SCIP_EXPORT
-SCIP_DEPRECATED
-void SCIPpermuteArray(
-   void**                array,              /**< array to be shuffled */
-   int                   begin,              /**< first included index that should be subject to shuffling
-                                              *   (0 for first array entry)
-                                              */
-   int                   end,                /**< first excluded index that should not be subject to shuffling
-                                              *   (array size for last array entry)
-                                              */
-   unsigned int*         randseed            /**< pointer to seed value for the random generator */
-   );
-
 /**@} */
 
 
@@ -2154,24 +2125,6 @@ void SCIPpermuteArray(
  * @{
  */
 
-
-/** computes set intersection (duplicates removed) of two integer arrays that are ordered ascendingly
- *
- * @deprecated Switch to SCIPcomputeArraysIntersectionInt().
- */
-SCIP_DEPRECATED
-SCIP_EXPORT
-SCIP_RETCODE SCIPcomputeArraysIntersection(
-   int*                  array1,             /**< first array (in ascending order) */
-   int                   narray1,            /**< number of entries of first array */
-   int*                  array2,             /**< second array (in ascending order) */
-   int                   narray2,            /**< number of entries of second array */
-   int*                  intersectarray,     /**< intersection of array1 and array2
-                                              *   (note: it is possible to use array1 for this input argument) */
-   int*                  nintersectarray     /**< pointer to store number of entries of intersection array
-                                              *   (note: it is possible to use narray1 for this input argument) */
-   );
-
 /** computes set intersection (duplicates removed) of two integer arrays that are ordered ascendingly */
 SCIP_EXPORT
 void SCIPcomputeArraysIntersectionInt(
@@ -2199,23 +2152,6 @@ void SCIPcomputeArraysIntersectionPtr(
                                               *   (note: it is possible to use narray1 for this input argument) */
 );
 
-/** computes set difference (duplicates removed) of two integer arrays that are ordered ascendingly
- *
- * @deprecated Switch to SCIPcomputeArraysSetminusInt().
- */
-SCIP_DEPRECATED
-SCIP_EXPORT
-SCIP_RETCODE SCIPcomputeArraysSetminus(
-   int*                  array1,             /**< first array (in ascending order) */
-   int                   narray1,            /**< number of entries of first array */
-   int*                  array2,             /**< second array (in ascending order) */
-   int                   narray2,            /**< number of entries of second array */
-   int*                  setminusarray,      /**< array to store entries of array1 that are not an entry of array2
-                                              *   (note: it is possible to use array1 for this input argument) */
-   int*                  nsetminusarray      /**< pointer to store number of entries of setminus array
-                                              *   (note: it is possible to use narray1 for this input argument) */
-   );
-
 /** computes set difference (duplicates removed) of two integer arrays that are ordered ascendingly */
 SCIP_EXPORT
 void SCIPcomputeArraysSetminusInt(
@@ -2382,7 +2318,7 @@ SCIP_Bool SCIPstrAtStart(
  * @{
  */
 
-/** returns, whether the given file exists */
+/** returns whether the given file exists */
 SCIP_EXPORT
 SCIP_Bool SCIPfileExists(
    const char*           filename            /**< file name */
