@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -39,12 +39,14 @@
 #include "scip/type_history.h"
 #include "scip/type_implics.h"
 #include "scip/type_lp.h"
+#include "scip/type_lpexact.h"
 #include "scip/type_misc.h"
 #include "scip/type_prop.h"
 #include "scip/type_result.h"
 #include "scip/type_retcode.h"
 #include "scip/type_scip.h"
 #include "scip/type_var.h"
+#include "scip/intervalarith.h"
 
 #ifdef NDEBUG
 #include "scip/struct_var.h"
@@ -131,7 +133,7 @@ int SCIPvarCompareActiveAndNegated(
    SCIP_VAR*             var2                /**< second problem variable */
    );
 
-/** comparison method for sorting active and negated variables by non-decreasing index, active and negated 
+/** comparison method for sorting active and negated variables by non-decreasing index, active and negated
  *  variables are handled as the same variables
  */
 SCIP_EXPORT
@@ -211,6 +213,16 @@ SCIP_RETCODE SCIPvarGetProbvarBound(
    SCIP_BOUNDTYPE*       boundtype           /**< pointer to type of bound: lower or upper bound */
    );
 
+/** transforms given variable, boundtype and exact bound to the corresponding active, fixed, or multi-aggregated variable
+ *  values
+ */
+SCIP_EXPORT
+SCIP_RETCODE SCIPvarGetProbvarBoundExact(
+   SCIP_VAR**            var,                /**< pointer to problem variable */
+   SCIP_RATIONAL*        bound,              /**< pointer to bound value to transform */
+   SCIP_BOUNDTYPE*       boundtype           /**< pointer to type of bound: lower or upper bound */
+   );
+
 /** transforms given variable and domain hole to the corresponding active, fixed, or multi-aggregated variable
  *  values
  */
@@ -231,6 +243,16 @@ SCIP_RETCODE SCIPvarGetOrigvarSum(
    SCIP_Real*            constant            /**< pointer to constant c in sum a*x + c */
    );
 
+/** retransforms given variable, scalar and constant to the corresponding original variable, scalar
+ *  and constant, if possible; if the retransformation is impossible, NULL is returned as variable
+ */
+SCIP_EXPORT
+SCIP_RETCODE SCIPvarGetOrigvarSumExact(
+   SCIP_VAR**            var,                /**< pointer to problem variable x in sum a*x + c */
+   SCIP_RATIONAL*        scalar,             /**< pointer to scalar a in sum a*x + c */
+   SCIP_RATIONAL*        constant            /**< pointer to constant c in sum a*x + c */
+   );
+
 /** returns whether the given variable is the direct counterpart of an original problem variable */
 SCIP_EXPORT
 SCIP_Bool SCIPvarIsTransformedOrigvar(
@@ -434,6 +456,18 @@ SCIP_VARSTATUS SCIPvarGetStatus(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** returns the status of the exact variable data */
+SCIP_EXPORT
+SCIP_VARSTATUS SCIPvarGetStatusExact(
+   SCIP_VAR*             var                 /**< scip variable */
+   );
+
+/** returns whether the variable has exact variable data */
+SCIP_EXPORT
+SCIP_Bool SCIPvarIsExact(
+   SCIP_VAR*             var                 /**< scip variable */
+   );
+
 /** returns whether the variable belongs to the original problem */
 SCIP_EXPORT
 SCIP_Bool SCIPvarIsOriginal(
@@ -458,9 +492,15 @@ SCIP_VARTYPE SCIPvarGetType(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets the implied integral type of the variable */
+SCIP_EXPORT
+SCIP_IMPLINTTYPE SCIPvarGetImplType(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** returns TRUE if the variable is of binary type; this is the case if:
  *  (1) variable type is binary
- *  (2) variable type is integer or implicit integer and 
+ *  (2) variable type is integer or implicit integer and
  *      (i)  the global lower bound is greater than or equal to zero
  *      (ii) the global upper bound is less than or equal to one
  */
@@ -469,12 +509,24 @@ SCIP_Bool SCIPvarIsBinary(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
-/** returns whether variable is of integral type (binary, integer, or implicit integer) */
+/** returns whether variable is of integral type (binary, integer, or implied integral of any type) */
 SCIP_EXPORT
 SCIP_Bool SCIPvarIsIntegral(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** returns whether variable is implied integral (weakly or strongly) */
+SCIP_EXPORT
+SCIP_Bool SCIPvarIsImpliedIntegral(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
+/** returns TRUE if the variable is integral, but not implied integral. */
+SCIP_EXPORT
+SCIP_Bool SCIPvarIsNonimpliedIntegral(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** returns whether variable's column should be present in the initial root LP */
 SCIP_EXPORT
 SCIP_Bool SCIPvarIsInitial(
@@ -540,6 +592,57 @@ int SCIPvarGetProbindex(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** returns position of variable in certificate */
+SCIP_EXPORT
+int SCIPvarGetCertificateIndex(
+   SCIP_VAR*             var                 /**< variable to get index for */
+   );
+
+/** sets index of variable in certificate */
+SCIP_EXPORT
+void SCIPvarSetCertificateIndex(
+   SCIP_VAR*             var,                /**< variable to set index for */
+   int                   certidx             /**< the index */
+   );
+
+/** sets index of variable in certificate */
+SCIP_EXPORT
+void SCIPvarSetUbCertificateIndexGlobal(
+   SCIP_VAR*             var,                /**< variable to set index for */
+   SCIP_Longint          certidx             /**< the index */
+   );
+
+/** sets index of variable in certificate */
+SCIP_EXPORT
+void SCIPvarSetLbCertificateIndexGlobal(
+   SCIP_VAR*             var,                /**< variable to set index for */
+   SCIP_Longint          certidx             /**< the index */
+   );
+
+/** returns index of variable bound in vipr certificate */
+SCIP_EXPORT
+SCIP_Longint SCIPvarGetLbCertificateIndexLocal(
+   SCIP_VAR*             var                 /**< variable to get index for */
+   );
+
+/** returns index of variable bound in vipr certificate */
+SCIP_EXPORT
+SCIP_Longint SCIPvarGetUbCertificateIndexLocal(
+   SCIP_VAR*             var                 /**< variable to get index for */
+   );
+
+/** returns index of variable bound in vipr certificate */
+SCIP_EXPORT
+SCIP_Longint SCIPvarGetLbCertificateIndexGlobal(
+   SCIP_VAR*             var                 /**< variable to get index for */
+   );
+
+/** returns index of variable bound in vipr certificate */
+SCIP_EXPORT
+SCIP_Longint SCIPvarGetUbCertificateIndexGlobal(
+   SCIP_VAR*             var                 /**< variable to get index for */
+   );
+
 /** gets transformed variable of ORIGINAL variable */
 SCIP_EXPORT
 SCIP_VAR* SCIPvarGetTransVar(
@@ -552,12 +655,30 @@ SCIP_COL* SCIPvarGetCol(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets column of COLUMN variable */
+SCIP_EXPORT
+SCIP_COLEXACT* SCIPvarGetColExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** returns whether the variable is a COLUMN variable that is member of the current LP */
 SCIP_EXPORT
 SCIP_Bool SCIPvarIsInLP(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets lower bound on absolute coefficient of a loose variable in (multi)aggregations of other variables */
+SCIP_EXPORT
+SCIP_Real SCIPvarGetMinAggrCoef(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
+/** gets upper bound on absolute coefficient of a loose variable in (multi)aggregations of other variables */
+SCIP_EXPORT
+SCIP_Real SCIPvarGetMaxAggrCoef(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets aggregation variable y of an aggregated variable x = a*y + c */
 SCIP_EXPORT
 SCIP_VAR* SCIPvarGetAggrVar(
@@ -570,12 +691,24 @@ SCIP_Real SCIPvarGetAggrScalar(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets aggregation scalar a of an aggregated variable x = a*y + c */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetAggrScalarExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets aggregation constant c of an aggregated variable x = a*y + c */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetAggrConstant(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets aggregation constant c of an aggregated variable x = a*y + c */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetAggrConstantExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets number n of aggregation variables of a multi aggregated variable x = a0*y0 + ... + a(n-1)*y(n-1) + c */
 SCIP_EXPORT
 int SCIPvarGetMultaggrNVars(
@@ -594,12 +727,24 @@ SCIP_Real* SCIPvarGetMultaggrScalars(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets vector of exact aggregation scalars a of a multi aggregated variable x = a0*y0 + ... + a(n-1)*y(n-1) + c */
+SCIP_EXPORT
+SCIP_RATIONAL** SCIPvarGetMultaggrScalarsExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets aggregation constant c of a multi aggregated variable x = a0*y0 + ... + a(n-1)*y(n-1) + c */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetMultaggrConstant(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets exact aggregation constant c of a multi aggregated variable x = a0*y0 + ... + a(n-1)*y(n-1) + c */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetMultaggrConstantExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets the negation of the given variable; may return NULL, if no negation is existing yet */
 SCIP_EXPORT
 SCIP_VAR* SCIPvarGetNegatedVar(
@@ -624,6 +769,18 @@ SCIP_Real SCIPvarGetObj(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets objective function value of variable */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetObjExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
+/** gets exact objective function value of variable */
+SCIP_EXPORT
+SCIP_INTERVAL SCIPvarGetObjInterval(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets the unchanged objective function value of variable (ignoring temproray changes performed in probing mode) */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetUnchangedObj(
@@ -636,12 +793,24 @@ SCIP_Real SCIPvarGetLbOriginal(
    SCIP_VAR*             var                 /**< original problem variable */
    );
 
+/** gets original lower bound of original problem variable (i.e. the bound set in problem creation) */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetLbOriginalExact(
+   SCIP_VAR*             var                 /**< original problem variable */
+   );
+
 /** gets original upper bound of original problem variable (i.e. the bound set in problem creation) */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetUbOriginal(
    SCIP_VAR*             var                 /**< original problem variable */
    );
 
+/** gets original upper bound of original problem variable (i.e. the bound set in problem creation) */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetUbOriginalExact(
+   SCIP_VAR*             var                 /**< original problem variable */
+   );
+
 /** gets the original hole list of an original variable */
 SCIP_EXPORT
 SCIP_HOLELIST* SCIPvarGetHolelistOriginal(
@@ -654,12 +823,24 @@ SCIP_Real SCIPvarGetLbGlobal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets global lower bound of variable */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetLbGlobalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets global upper bound of variable */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetUbGlobal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets global upper bound of variable */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetUbGlobalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets the global hole list of an active variable */
 SCIP_EXPORT
 SCIP_HOLELIST* SCIPvarGetHolelistGlobal(
@@ -672,24 +853,48 @@ SCIP_Real SCIPvarGetBestBoundGlobal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets best global bound of variable with respect to the objective function */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetBestBoundGlobalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets worst global bound of variable with respect to the objective function */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetWorstBoundGlobal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets worst global bound of variable with respect to the objective function */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetWorstBoundGlobalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets current lower bound of variable */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetLbLocal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets current lower bound of variable */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetLbLocalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets current upper bound of variable */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetUbLocal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets current upper bound of variable */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetUbLocalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets the current hole list of an active variable */
 SCIP_EXPORT
 SCIP_HOLELIST* SCIPvarGetHolelistLocal(
@@ -702,24 +907,48 @@ SCIP_Real SCIPvarGetBestBoundLocal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets best local bound of variable with respect to the objective function */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetBestBoundLocalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets worst local bound of variable with respect to the objective function */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetWorstBoundLocal(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets worst local bound of variable with respect to the objective function */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetWorstBoundLocalExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets type (lower or upper) of best bound of variable with respect to the objective function */
 SCIP_EXPORT
 SCIP_BOUNDTYPE SCIPvarGetBestBoundType(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets type (lower or upper) of best bound of variable with respect to the objective function */
+SCIP_EXPORT
+SCIP_BOUNDTYPE SCIPvarGetBestBoundTypeExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets type (lower or upper) of worst bound of variable with respect to the objective function */
 SCIP_EXPORT
 SCIP_BOUNDTYPE SCIPvarGetWorstBoundType(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets type (lower or upper) of worst bound of variable with respect to the objective function */
+SCIP_EXPORT
+SCIP_BOUNDTYPE SCIPvarGetWorstBoundTypeExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets lazy lower bound of variable */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetLbLazy(
@@ -806,7 +1035,7 @@ SCIP_Real* SCIPvarGetVubConstants(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
-/** gets number of implications  y <= b or y >= b for x == 0 or x == 1 of given active problem variable x, 
+/** gets number of implications  y <= b or y >= b for x == 0 or x == 1 of given active problem variable x,
  *  there are no implications for nonbinary variable x
  */
 SCIP_EXPORT
@@ -828,7 +1057,7 @@ SCIP_VAR** SCIPvarGetImplVars(
    );
 
 /** gets array with implication types of implications  y <= b or y >= b for x == 0 or x == 1 of given active problem
- *  variable x (SCIP_BOUNDTYPE_UPPER if y <= b, SCIP_BOUNDTYPE_LOWER if y >= b), 
+ *  variable x (SCIP_BOUNDTYPE_UPPER if y <= b, SCIP_BOUNDTYPE_LOWER if y >= b),
  *  there are no implications for nonbinary variable x
  */
 SCIP_EXPORT
@@ -877,6 +1106,13 @@ SCIP_Real SCIPvarGetLPSol(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets primal LP solution value of variable */
+SCIP_EXPORT
+void SCIPvarGetLPSolExact(
+   SCIP_VAR*             var,                /**< problem variable */
+   SCIP_RATIONAL*        res                 /**< store the resulting value */
+   );
+
 /** gets primal NLP solution value of variable */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetNLPSol(
@@ -967,8 +1203,11 @@ void SCIPvarMarkRelaxationOnly(
 #define SCIPvarIsNegated(var)           ((var)->varstatus == SCIP_VARSTATUS_NEGATED)
 #define SCIPvarGetType(var)             ((SCIP_VARTYPE)((var)->vartype))
 #define SCIPvarIsBinary(var)            ((var)->vartype == SCIP_VARTYPE_BINARY || \
-      ((var)->vartype != SCIP_VARTYPE_CONTINUOUS && (var)->glbdom.lb >= 0.0 && (var)->glbdom.ub <= 1.0))
-#define SCIPvarIsIntegral(var)          ((var)->vartype != SCIP_VARTYPE_CONTINUOUS)
+      (((var)->vartype != SCIP_VARTYPE_CONTINUOUS || (var)->varimpltype != SCIP_IMPLINTTYPE_NONE) \
+      && (var)->glbdom.lb >= 0.0 && (var)->glbdom.ub <= 1.0))
+#define SCIPvarIsIntegral(var)          ((var)->vartype != SCIP_VARTYPE_CONTINUOUS || (var)->varimpltype != SCIP_IMPLINTTYPE_NONE)
+#define SCIPvarIsImpliedIntegral(var)   ((var)->varimpltype != SCIP_IMPLINTTYPE_NONE)
+#define SCIPvarIsNonimpliedIntegral(var) ((var)->vartype != SCIP_VARTYPE_CONTINUOUS && (var)->varimpltype == SCIP_IMPLINTTYPE_NONE)
 #define SCIPvarIsInitial(var)           (var)->initial
 #define SCIPvarIsRemovable(var)         (var)->removable
 #define SCIPvarIsDeleted(var)           (var)->deleted
@@ -981,6 +1220,8 @@ void SCIPvarMarkRelaxationOnly(
 #define SCIPvarGetTransVar(var)         (var)->data.original.transvar
 #define SCIPvarGetCol(var)              (var)->data.col
 #define SCIPvarIsInLP(var)              ((var)->varstatus == SCIP_VARSTATUS_COLUMN && SCIPcolIsInLP((var)->data.col))
+#define SCIPvarGetMinAggrCoef(var)      (var)->data.loose.minaggrcoef
+#define SCIPvarGetMaxAggrCoef(var)      (var)->data.loose.maxaggrcoef
 /* use different name for var - otherwise we have clash with the var at the end */
 #define SCIPvarGetAggrVar(war)          (war)->data.aggregate.var
 #define SCIPvarGetAggrScalar(var)       (var)->data.aggregate.scalar
@@ -1053,6 +1294,13 @@ SCIP_Real SCIPvarGetLPSol_rec(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets primal LP solution value of variable */
+SCIP_EXPORT
+void SCIPvarGetLPSolExact_rec(
+   SCIP_VAR*             var,                /**< problem variable */
+   SCIP_RATIONAL*        res                 /**< store the resulting value */
+   );
+
 /** gets primal NLP solution value of variable */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetNLPSol_rec(
@@ -1065,6 +1313,12 @@ SCIP_Real SCIPvarGetPseudoSol(
    SCIP_VAR*             var                 /**< problem variable */
    );
 
+/** gets pseudo solution value of variable */
+SCIP_EXPORT
+SCIP_RATIONAL* SCIPvarGetPseudoSolExact(
+   SCIP_VAR*             var                 /**< problem variable */
+   );
+
 /** gets current LP or pseudo solution value of variable */
 SCIP_EXPORT
 SCIP_Real SCIPvarGetSol(
@@ -1072,6 +1326,14 @@ SCIP_Real SCIPvarGetSol(
    SCIP_Bool             getlpval            /**< should the LP solution value be returned? */
    );
 
+/** gets current LP or pseudo solution value of variable */
+SCIP_EXPORT
+void SCIPvarGetSolExact(
+   SCIP_VAR*             var,                /**< problem variable */
+   SCIP_RATIONAL*        res,                /**< the resulting value */
+   SCIP_Bool             getlpval            /**< should the LP solution value be returned? */
+   );
+
 /** returns the solution of the variable in the last root node's relaxation, if the root relaxation is not yet
  *  completely solved, zero is returned
  */
@@ -1155,54 +1417,6 @@ SCIP_BDCHGINFO* SCIPvarGetBdchgInfo(
    SCIP_Bool             after               /**< should the bound change with given index be included? */
    );
 
-/** returns lower bound of variable directly before or after the bound change given by the bound change index
- *  was applied
- *
- *  @deprecated Please use SCIPgetVarLbAtIndex()
- */
-SCIP_EXPORT
-SCIP_Real SCIPvarGetLbAtIndex(
-   SCIP_VAR*             var,                /**< problem variable */
-   SCIP_BDCHGIDX*        bdchgidx,           /**< bound change index representing time on path to current node */
-   SCIP_Bool             after               /**< should the bound change with given index be included? */
-   );
-
-/** returns upper bound of variable directly before or after the bound change given by the bound change index
- *  was applied
- *
- *  @deprecated Please use SCIPgetVarUbAtIndex()
- */
-SCIP_EXPORT
-SCIP_Real SCIPvarGetUbAtIndex(
-   SCIP_VAR*             var,                /**< problem variable */
-   SCIP_BDCHGIDX*        bdchgidx,           /**< bound change index representing time on path to current node */
-   SCIP_Bool             after               /**< should the bound change with given index be included? */
-   );
-
-/** returns lower or upper bound of variable directly before or after the bound change given by the bound change index
- *  was applied
- *
- *  @deprecated Please use SCIPgetVarBdAtIndex()
- */
-SCIP_EXPORT
-SCIP_Real SCIPvarGetBdAtIndex(
-   SCIP_VAR*             var,                /**< problem variable */
-   SCIP_BOUNDTYPE        boundtype,          /**< type of bound: lower or upper bound */
-   SCIP_BDCHGIDX*        bdchgidx,           /**< bound change index representing time on path to current node */
-   SCIP_Bool             after               /**< should the bound change with given index be included? */
-   );
-
-/** returns whether the binary variable was fixed at the time given by the bound change index
- *
- *  @deprecated Please use SCIPgetVarWasFixedAtIndex()
- */
-SCIP_EXPORT
-SCIP_Bool SCIPvarWasFixedAtIndex(
-   SCIP_VAR*             var,                /**< problem variable */
-   SCIP_BDCHGIDX*        bdchgidx,           /**< bound change index representing time on path to current node */
-   SCIP_Bool             after               /**< should the bound change with given index be included? */
-   );
-
 /** returns the last bound change index, at which the bounds of the given variable were tightened */
 SCIP_EXPORT
 SCIP_BDCHGIDX* SCIPvarGetLastBdchgIndex(
@@ -1228,6 +1442,19 @@ SCIP_Bool SCIPvarWasFixedEarlier(
    SCIP_VAR*             var2                /**< second binary variable */
    );
 
+/** for a given array of variables, this function counts the numbers of variables for each variable and implied type combination */
+SCIP_EXPORT
+void SCIPvarsCountTypes(
+   SCIP_VAR**            vars,               /**< array of variables to count the types for */
+   int                   nvars,              /**< number of variables in the array */
+   int*                  nbinvars,           /**< pointer to store number of binary variables or NULL if not needed */
+   int*                  nintvars,           /**< pointer to store number of integer variables or NULL if not needed */
+   int*                  nbinimplvars,       /**< pointer to store number of binary implicit integral vars or NULL if not needed */
+   int*                  nintimplvars,       /**< pointer to store number of integer implicit integral vars or NULL if not needed */
+   int*                  ncontimplvars,      /**< pointer to store number of continuous implicit integral vars or NULL if not needed */
+   int*                  ncontvars           /**< pointer to store number of continuous variables or NULL if not needed */
+   );
+
 /**
  * @name Public SCIP_BDCHGIDX Methods
  *
@@ -1372,6 +1599,12 @@ SCIP_Real SCIPboundchgGetNewbound(
    SCIP_BOUNDCHG*        boundchg            /**< bound change data */
    );
 
+/** returns the lp solution value in the branching data of the bound change data */
+SCIP_EXPORT
+SCIP_Real SCIPboundchgGetLPSolVal(
+   SCIP_BOUNDCHG*        boundchg            /**< bound change data */
+   );
+
 /** returns the variable of the bound change in the bound change data */
 SCIP_EXPORT
 SCIP_VAR* SCIPboundchgGetVar(
@@ -1475,13 +1708,14 @@ SCIP_HOLELIST* SCIPholelistGetNext(
 #define SCIPbdchginfoIsTighter(bdchginfo1,bdchginfo2) ((bdchginfo1)->boundtype == SCIP_BOUNDTYPE_LOWER \
       ? (bdchginfo1)->newbound > bdchginfo2->newbound : (bdchginfo1)->newbound < bdchginfo2->newbound)
 #define SCIPboundchgGetNewbound(boundchg)      ((boundchg)->newbound)
+#define SCIPboundchgGetLPSolVal(boundchg) ((boundchg)->data.branchingdata.lpsolval)
 #define SCIPboundchgGetVar(boundchg)           ((boundchg)->var)
 #define SCIPboundchgGetBoundchgtype(boundchg)  ((SCIP_BOUNDCHGTYPE)((boundchg)->boundchgtype))
 #define SCIPboundchgGetBoundtype(boundchg)     ((SCIP_BOUNDTYPE)((boundchg)->boundtype))
 #define SCIPboundchgIsRedundant(boundchg)      ((boundchg)->redundant)
 #define SCIPdomchgGetNBoundchgs(domchg)        ((domchg) != NULL ? (domchg)->domchgbound.nboundchgs : 0)
 #define SCIPdomchgGetBoundchg(domchg, pos)     (&(domchg)->domchgbound.boundchgs[pos])
-#define SCIPholelistGetLeft(holelist)          ((holelist)->hole.left) 
+#define SCIPholelistGetLeft(holelist)          ((holelist)->hole.left)
 #define SCIPholelistGetRight(holelist)         ((holelist)->hole.right)
 #define SCIPholelistGetNext(holelist)          ((holelist)->next)
 
