@@ -40,10 +40,12 @@
 #include "scip/type_clock.h"
 #include "scip/type_dcmp.h"
 #include "scip/type_event.h"
+#include "scip/type_iisfinder.h"
 #include "scip/type_interrupt.h"
 #include "scip/type_mem.h"
 #include "scip/type_message.h"
 #include "scip/type_lp.h"
+#include "scip/type_lpexact.h"
 #include "scip/type_nlp.h"
 #include "scip/type_implics.h"
 #include "scip/type_prob.h"
@@ -86,10 +88,11 @@ struct Scip
    SCIP_REOPT*           reopt;              /**< reoptimization data */
 
    /* TRANSFORMED */
-   SCIP_EVENTFILTER*     eventfilter;        /**< event filter for global (not variable dependent) events */
    SCIP_EVENTQUEUE*      eventqueue;         /**< event queue to cache events and process them later (bound change events) */
+   SCIP_EVENTFILTER*     eventfilter;        /**< global event filter */
    SCIP_BRANCHCAND*      branchcand;         /**< storage for branching candidates */
    SCIP_LP*              lp;                 /**< LP data */
+   SCIP_LPEXACT*         lpexact;            /**< exact LP data */
    SCIP_NLP*             nlp;                /**< NLP data */
    SCIP_RELAXATION*      relaxation;         /**< global relaxation data */
    SCIP_PRIMAL*          primal;             /**< primal data and solution storage */
@@ -102,6 +105,7 @@ struct Scip
    SCIP_PRICESTORE*      pricestore;         /**< storage for priced variables */
    SCIP_SEPASTORE*       sepastore;          /**< storage for separated cuts */
    SCIP_SEPASTORE*       sepastoreprobing;   /**< storage for separated cuts during probing mode */
+   SCIP_SEPASTOREEXACT*  sepastoreexact;     /**< storage for exact cuts */
    SCIP_CONFLICTSTORE*   conflictstore;      /**< storage for conflicts */
    SCIP_CUTPOOL*         cutpool;            /**< global cut pool */
    SCIP_CUTPOOL*         delayedcutpool;     /**< global delayed cut pool */
@@ -109,6 +113,9 @@ struct Scip
    /* PARALLEL */
    SCIP_SYNCSTORE*       syncstore;          /**< the data structure for storing synchronization information */
    SCIP_CONCURRENT*      concurrent;         /**< data required for concurrent solve */
+
+   /* IIS */
+   SCIP_IIS*             iis;                /**< the data structure for storing IIS information */
 };
 
 #ifdef __cplusplus
