@@ -73,6 +73,16 @@ SCIP_RETCODE SCIPfreeSymgraph(
    SYM_GRAPH**           graph               /**< pointer to symmetry detection graph */
    );
 
+/**  clears data of symmetry detection graph */
+SCIP_EXPORT
+SCIP_RETCODE SCIPclearSymgraph(
+   SCIP*                 scip,               /**< SCIP data structure */
+   SYM_GRAPH*            graph,              /**< symmetry detection graph */
+   SCIP_VAR**            symvars,            /**< variables used in symmetry detection */
+   int                   nsymvars,           /**< number of variables used in symmetry detection */
+   SYM_SYMTYPE           symtype             /**< type of symmetries encoded in graph */
+   );
+
 /** copies an existing graph and changes variable nodes according to a permutation */
 SCIP_EXPORT
 SCIP_RETCODE SCIPcopySymgraph(
@@ -83,6 +93,17 @@ SCIP_RETCODE SCIPcopySymgraph(
    SYM_SPEC              fixedtype           /**< variable types that must be fixed by symmetries */
    );
 
+/** copies a symmetry detection graph into another symmetry detection graph */
+SCIP_EXPORT
+SCIP_RETCODE SCIPcopySymgraphAsSubgraph(
+   SCIP*                 scip,               /**< SCIP pointer */
+   SYM_GRAPH*            sourcegraph,        /**< graph to be copied */
+   SYM_GRAPH*            targetgraph,        /**< graph into which copy shall be included */
+   SCIP_CONS*            sourcecons,         /**< constraint associated with sourcegraph */
+   int*                  rootidx             /**< pointer to hold index of root node of sourcegraph in targetgraph
+                                              *   (or -1 if root cannot be detected) */
+   );
+
 /** adds a symmetry detection graph for a linear constraint to existing graph
  *
  *  For permutation symmetries, a constraint node is added that is connected to all
@@ -321,16 +342,6 @@ SCIP_Bool SCIPhasGraphUniqueEdgetype(
    SYM_GRAPH*            graph               /**< symmetry detection graph */
    );
 
-/** creates consnodeperm array for symmetry detection graph
- *
- *  @note @p colors of symmetry detection graph must have been computed
- */
-SCIP_EXPORT
-SCIP_RETCODE SCIPallocateSymgraphConsnodeperm(
-   SCIP*                 scip,               /**< SCIP data structure */
-   SYM_GRAPH*            graph               /**< symmetry detection graph */
-   );
-
 /** creates consnodeperm array for symmetry detection graph
  *
  *  @note @p colors of symmetry detection graph must have been computed
