@@ -70,6 +70,7 @@ SCIP_RETCODE SCIPtableCreate(
    SCIP_DECL_TABLEINITSOL ((*tableinitsol)), /**< solving process initialization method of statistics table */
    SCIP_DECL_TABLEEXITSOL ((*tableexitsol)), /**< solving process deinitialization method of statistics table */
    SCIP_DECL_TABLEOUTPUT ((*tableoutput)),   /**< output method */
+   SCIP_DECL_TABLECOLLECT((*tablecollect)),  /**< report table data as SCIP_DATATREE */
    SCIP_TABLEDATA*       tabledata,          /**< statistics table data */
    int                   position,           /**< position of statistics table */
    SCIP_STAGE            earlieststage       /**< output of the statistics table is only printed from this stage onwards */
@@ -108,10 +109,18 @@ SCIP_RETCODE SCIPtableExitsol(
 /** output statistics table to screen */
 SCIP_RETCODE SCIPtableOutput(
    SCIP_TABLE*           table,              /**< statistics table */
+   BMS_BLKMEM*           blkmem,             /**< block memory */
    SCIP_SET*             set,                /**< global SCIP settings */
    FILE*                 file                /**< output file (or NULL for standard output) */
    );
 
+/** collects statistics table data */
+SCIP_RETCODE SCIPtableCollect(
+   SCIP_TABLE*           table,              /**< statistics table */
+   SCIP_SET*             set,                /**< global SCIP settings */
+   SCIP_DATATREE*        datatree            /**< data tree where to add table data */
+   );
+
 #ifdef __cplusplus
 }
 #endif
